==> chance-paddy-1.1.2.2a1.tar.gz: chance-paddy-1.1.2.2a1/paddy/constant.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# File: constant.py
# Author: Jimin Huang <huangjimin@whu.edu.cn>
# Date: 26.09.2017

TRADE_EASY = 0
TRADE_TEST = -1

TRADERS = {
    TRADE_EASY: 'trade_easy',
    TRADE_TEST: 'test_trader'
}

MAX_REQUEST = 3
SLEEP_TIME = 3

FAKE_ACCOUNT_RESPONSE = {
    "subAccounts": {
        u'人民币': {
            u'冻结金额': 0,
            u'参考总资产（含港股通）': 367.94999999999999,
            u'参考股票市值(含港股通)': 245,
            u"可取金额": 122.95,
            u"可用金额": 122.95,
            u"当日盈亏": "‐‐‐‐‐‐",
            u"持仓盈亏": -12,
            u"资金余额": 122.95
        }
    },
    "count": 1,
    "dataTable": {
        "columns": [
            u"证券代码", u"证券名称", u"股票余额", u"可用余额",
            u"冻结数量", u"盈亏", u"成本价", u"盈亏比(%)", u"市价",
            u"市值", u"累计盈亏", u"市场代码", u"交易市场", u"股东帐户",
            u"实际数量", u"单位数量", u"资讯", u"买入均价"
        ],
        "rows": [
            [
                "600022", u"山东钢铁", "100", "100", "0", "‐12.000",
                "2.570", "‐4.67", "2.450", "245.000", "0.000", "2",
                u"上海Ａ股", "A694868976", "100", "1", "", "2.520"
            ],
            [
                "000001", u"平安银行", "100", "100", "0", "‐12.000", "12",
                "‐4.67", "11", "1100.000", "0.000", "2", u"深圳Ａ股",
                "A694868976", "100", "1", "", "12"
            ]
        ]
    },
    "startDate": "1970‐01‐01T08:00:00",
    "endDate": "1970‐01‐01T08:00:00",
    "updateDate": "2017‐09‐25T10:05:43"
}


FAKE_ENTRUST_RESPONSE = {
    "count": 4,
    "dataTable": {
        "columns": [
            u"备注",
            u"操作",
            u"证券代码",
            u"证券名称",
            u"委托数量",
            u"成交数量",
            u"委托价格",
            u"成交均价",
            u"撤消数量",
            u"委托时间",
            u"委托日期",
            u"合同编号"
        ],
        "rows": [
            [
                u"已成",
                u"买入",
                "600022",
                u"山东钢铁",
                "100",
                "100",
                "2.540",
                "2.540",
                "0",
                "10:33:45.675",
                "20170913",
                "10381"
            ],
            [
                u"已撤",
                u"买入已撤",
                "600022",
                u"山东钢铁",
                "100",
                "0",
                "2.400",
                "0.000",
                "100",
                "10:37:49.013",
                "20170913",
                "10775"
            ]
        ]
    },
    "startDate": "1970‐01‐01T08:00:00",
    "endDate": "1970‐01‐01T08:00:00",
    "updateDate": "2017‐09‐13T10:51:39"
}

ENTRUST_STATE_DICT = {
    u'已报': 0, u'已成': 1, u'部成': 2, u'部分成交': 2, u'已撤': 3,
    u'已报待撤': 4, u'已确认': 5, u'废单': 6
}

FAKE_CANCELLABLE_ENTRUSTS_RESPONSE = {
    "count": 2,
    "dataTable": {
        "columns": [
            u"明細",
            u"证券代码",
            u"证券名称",
            u"备注",
            u"委托数量",
            u"成交数量",
            u"委托价格",
            u"成交均价",
            u"操作",
            u"委托时间",
            u"委托日期",
            u"合同编号",
            u"交易市场",
            u"股东帐户",
            u"订单类型"
        ],
        "rows": [
            [
                "test",
                "600022",
                u"山东钢铁",
                u"已报",
                "100",
                "0",
                "2.300",
                "0.000",
                u"买入",
                "10:41:11.579",
                "20170913",
                "11106",
                u"上海Ａ股",
                "A141409591",
                u"买卖"
            ],
            [
                "test2",
                "600022",
                u"山东钢铁",
                u"已报",
                "100",
                "0",
                "2.400",
                "0.000",
                u"买入",
                "10:50:54.499",
                "20170913",
                "11852",
                u"上海Ａ股",
                "A141409591",
                u"买卖"
            ]
        ]
    },
    "startDate": "1970-01-01T08:00:00",
    "endDate": "1970-01-01T08:00:00",
    "updateDate": "2017-09-13T10:52:46"
}

==> chance-paddy-1.2.2.tar.gz: chance-paddy-1.2.2/paddy/constant.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# File: constant.py
# Author: Jimin Huang <huangjimin@whu.edu.cn>
# Date: 26.09.2017

TRADE_EASY = 0
TRADE_TEST = -1

TRADERS = {
    TRADE_EASY: 'trade_easy',
    TRADE_TEST: 'test_trader'
}

MAX_REQUEST = 3
SLEEP_TIME = 3

FAKE_ACCOUNT_RESPONSE = {
    "subAccounts": {
        u'人民币': {
            u'冻结金额': 0,
            u"可取金额": 122.95,
            u"可用金额": 122.95,
            u"当日盈亏": "‐‐‐‐‐‐",
            u'总 资 产': 367.94999999999999,
            u"持仓盈亏": -12,
            u'股票市值': 245,
            u"资金余额": 122.95
        }
    },
    "count": 1,
    "dataTable": {
        "columns": [
            u"证券代码", u"证券名称", u"股票余额", u"可用余额",
            u"冻结数量", u"盈亏", u"成本价", u"盈亏比(%)", u"市价",
            u"市值", u"累计盈亏", u"市场代码", u"交易市场", u"股东帐户",
            u"实际数量", u"单位数量", u"资讯", u"买入均价"
        ],
        "rows": [
            [
                "600022", u"山东钢铁", "100", "100", "0", "‐12.000",
                "2.570", "‐4.67", "2.450", "245.000", "0.000", "2",
                u"上海Ａ股", "A694868976", "100", "1", "", "2.520"
            ],
            [
                "000001", u"平安银行", "100", "100", "0", "‐12.000", "12",
                "‐4.67", "11", "1100.000", "0.000", "2", u"深圳Ａ股",
                "A694868976", "100", "1", "", "12"
            ]
        ]
    },
    "startDate": "1970‐01‐01T08:00:00",
    "endDate": "1970‐01‐01T08:00:00",
    "updateDate": "2017‐09‐25T10:05:43"
}


FAKE_ENTRUST_RESPONSE = {
    "count": 4,
    "dataTable": {
        "columns": [
            u"备注",
            u"操作",
            u"证券代码",
            u"证券名称",
            u"委托数量",
            u"成交数量",
            u"委托价格",
            u"成交均价",
            u"撤消数量",
            u"委托时间",
            u"委托日期",
            u"合同编号"
        ],
        "rows": [
            [
                u"已成",
                u"买入",
                "600022",
                u"山东钢铁",
                "100",
                "100",
                "2.540",
                "2.540",
                "0",
                "10:33:45.675",
                "20170913",
                "10381"
            ],
            [
                u"已撤",
                u"买入已撤",
                "600022",
                u"山东钢铁",
                "100",
                "0",
                "2.400",
                "0.000",
                "100",
                "10:37:49.013",
                "20170913",
                "10775"
            ]
        ]
    },
    "startDate": "1970‐01‐01T08:00:00",
    "endDate": "1970‐01‐01T08:00:00",
    "updateDate": "2017‐09‐13T10:51:39"
}

ENTRUST_STATE_DICT = {
    u'已报': 0, u'已成': 1, u'部成': 2, u'部分成交': 2, u'已撤': 3,
    u'已报待撤': 4, u'已确认': 5, u'废单': 6
}

FAKE_CANCELLABLE_ENTRUSTS_RESPONSE = {
    "count": 2,
    "dataTable": {
        "columns": [
            u"明細",
            u"证券代码",
            u"证券名称",
            u"备注",
            u"委托数量",
            u"成交数量",
            u"委托价格",
            u"成交均价",
            u"操作",
            u"委托时间",
            u"委托日期",
            u"合同编号",
            u"交易市场",
            u"股东帐户",
            u"订单类型"
        ],
        "rows": [
            [
                "test",
                "600022",
                u"山东钢铁",
                u"已报",
                "100",
                "0",
                "2.300",
                "0.000",
                u"买入",
                "10:41:11.579",
                "20170913",
                "11106",
                u"上海Ａ股",
                "A141409591",
                u"买卖"
            ],
            [
                "test2",
                "600022",
                u"山东钢铁",
                u"已报",
                "100",
                "0",
                "2.400",
                "0.000",
                u"买入",
                "10:50:54.499",
                "20170913",
                "11852",
                u"上海Ａ股",
                "A141409591",
                u"买卖"
            ]
        ]
    },
    "startDate": "1970-01-01T08:00:00",
    "endDate": "1970-01-01T08:00:00",
    "updateDate": "2017-09-13T10:52:46"
}
